Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4706)

Unified Diff: chrome/browser/captive_portal/captive_portal_browsertest.cc

Issue 10698068: chrome: Put browser_navigator.h into chrome namespace. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: already in chrome namespace Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/extensions/api/tabs/tabs.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/captive_portal/captive_portal_browsertest.cc
diff --git a/chrome/browser/captive_portal/captive_portal_browsertest.cc b/chrome/browser/captive_portal/captive_portal_browsertest.cc
index fc9f3b254c07f55a851095bcff58475be81bf6fe..12a9d6ca07bf5fce4d53da3e480359062926fb19 100644
--- a/chrome/browser/captive_portal/captive_portal_browsertest.cc
+++ b/chrome/browser/captive_portal/captive_portal_browsertest.cc
@@ -25,8 +25,8 @@
#include "chrome/browser/ui/browser_finder.h"
#include "chrome/browser/ui/browser_navigator.h"
#include "chrome/browser/ui/browser_tabstrip.h"
-#include "chrome/browser/ui/tab_contents/tab_contents_iterator.h"
#include "chrome/browser/ui/tab_contents/tab_contents.h"
+#include "chrome/browser/ui/tab_contents/tab_contents_iterator.h"
#include "chrome/common/chrome_notification_types.h"
#include "chrome/common/chrome_paths.h"
#include "chrome/common/chrome_switches.h"
@@ -1846,13 +1846,13 @@ IN_PROC_BROWSER_TEST_F(CaptivePortalBrowserTest, DISABLED_TwoWindows) {
MultiNavigationObserver navigation_observer;
// Navigate the tab in the inactive browser to an SSL timeout. Have to use
// browser::NavigateParams and NEW_BACKGROUND_TAB to avoid activating the
// window.
- browser::NavigateParams params(inactive_browser,
- GURL(kMockHttpsQuickTimeoutUrl),
- content::PAGE_TRANSITION_TYPED);
+ chrome::NavigateParams params(inactive_browser,
+ GURL(kMockHttpsQuickTimeoutUrl),
+ content::PAGE_TRANSITION_TYPED);
params.disposition = NEW_BACKGROUND_TAB;
- params.window_action = browser::NavigateParams::NO_ACTION;
+ params.window_action = chrome::NavigateParams::NO_ACTION;
ui_test_utils::NavigateToURL(&params);
navigation_observer.WaitForNavigations(2);
« no previous file with comments | « no previous file | chrome/browser/extensions/api/tabs/tabs.cc » ('j') | no next file with comments »
@@ -1846,13 +1846,13 @@ IN_PROC_BROWSER_TEST_F(CaptivePortalBrowserTest, DISABLED_TwoWindows) {
MultiNavigationObserver navigation_observer;
// Navigate the tab in the inactive browser to an SSL timeout. Have to use
- // browser::NavigateParams and NEW_BACKGROUND_TAB to avoid activating the
+ // chrome::NavigateParams and NEW_BACKGROUND_TAB to avoid activating the
// window.

Powered by Google App Engine
This is Rietveld 408576698